@@ -14,7 +14,7 @@ use open ':std', ':encoding(UTF-8)'; # force stdin, stdout, stderr into utf8
 
 use Safe::Isa;
 use Feature::Compat::Try;
-use Path::Tiny;
+use Mojo::File 'path';
 
 use if $ENV{AUTHOR_TESTING}, 'Test2::Warnings' => ':fail_on_warning'; # hooks into done_testing unless overridden
 use Test::JSON::Schema::Acceptance 1.029;
@@ -116,7 +116,7 @@ sub acceptance_tests (%options) {
   memory_cycle_ok($js_short_circuit, 'no leaks in the short-circuiting evaluator object')
     if not $ENV{NO_SHORT_CIRCUIT};
 
-  path('t/results/'.$options{output_file})->spew_utf8($accepter->results_text)
+  path('t/results/'.$options{output_file})->spew($accepter->results_text, 'UTF-8')
     if $ENV{AUTHOR_TESTING};
 }
 
